==> webgui_7.6.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_MatrixListing.pm <==
package WebGUI::i18n::English::Asset_MatrixListing;

use strict; 

our $I18N = { 
    'assetName' => {
        message => q|Matrix Listing|,
        lastUpdated => 0,
    },

    'edit matrix listing title' => {
        message => q|Edit/Add Listing|,
        lastUpdated => 0,
    },

    'template description' => {
        message => q|Select a template to be used to display the default view of the Matrix.|,
        lastUpdated => 0,
    },

    'template label' => {
        message => q|Matrix Listing Template|,
        lastUpdated => 0,
    },

    'screenshots description' => {
        message => q|Upload a picture of the product, or a screen shot if it's a software package.|,
        lastUpdated => 0,
    },

    'screenshots label' => {
        message => q|Screenshots/Photos|,
        lastUpdated => 0,
    },

    'description description' => {
        message => q|Please give a general description of the product.  Specific details can be rated in the form
fields below.|,
        lastUpdated => 0,
    },

    'description label' => {
        message => q|Description|,
        lastUpdated => 0,
    },

    'edit label' => {
        message => q|Edit|,
        lastUpdated => 0,
    },

    'version description' => {
        message => q|Enter the version/edition/model number for the product.|,
        lastUpdated => 0,
    },

    'version label' => {
        message => q|Version/Model|,
        lastUpdated => 0,
    },

    'last updated label' => {
        message => q|Last Updated|,
        lastUpdated => 0,
    },

    'web site label' => {
        message => q|Web Site|,
        lastUpdated => 0,
    },

    'message sent message' => {
        message => q|Message sent.|,
        lastUpdated => 0,
    },

    'contact maintainer label' => {
        message => q|Contact Maintainer|,
        lastUpdated => 0,
    },

    'maintainer description' => {
        message => q|If left blank, this will be the name of the user who created this product listing.  The
        listing maintainer is allowed to edit this listing, even if they are not members of the group
        to add or edit listings.|,
        lastUpdated => 0,
    },

    'maintainer label' => {
        message => q|Maintainer|,
        lastUpdated => 0,
    },

    'manufacturer label' => {
        message => q|Manufacturer|,
        lastUpdated => 0,
    },
    
    'manufacturerName description' => {
        message => q|The name of the company that manufactures the product or provides the service represented in
this listing.|,
        lastUpdated => 0,
    },

    'manufacturerName label' => {
        message => q|Manufacturer Name|,
        lastUpdated => 0,
    },

    'manufacturerURL description' => {
        message => q|If the manufacturer has a website, enter the complete URL for it here.|,
        lastUpdated => 0,
    },

    'manufacturerURL label' => {
        message => q|Manufacturer URL|,
        lastUpdated => 0,
    },

    'product name label' => {
        message => q|Product Name|,
        lastUpdated => 0,
    },

    'product name description' => {
        message => q|Enter the name of the product. If there are entries for the product with different revisions,
it would be best to make sure the names are the same.|,
        lastUpdated => 0,
    },

    'productURL description' => {
        message => q|If the product has its own website, enter the complete URL for it here.|,
        lastUpdated => 0,
    },

    'productURL label' => {
        message => q|Product URL|,
        lastUpdated => 0,
    },

    'mean label' => {
        message => q|Mean|,
        lastUpdated => 0,
    },

    'median label' => {
        message => q|Median|,
        lastUpdated => 0,
    },

    'count label' => {
        message => q|Count|,
        lastUpdated => 0,
    },

    'worst label' => {
        message => q|Worst|,
        lastUpdated => 0,
    },

    'respectable label' => {
        message => q|Respectable|,
        lastUpdated => 0,
    },

    'best label' => {
        message => q|Best|,
        lastUpdated => 0,
    },

    'your email label' => {
        message => q|Your Email Address|,
        lastUpdated => 0,
    },

    'report error label' => {
        message => q|Report an error.|,
        lastUpdated => 0,
    },

    'general comment label' => {
        message => q|General comment.|,
        lastUpdated => 0,
    },

    'request type label' => {
        message => q|Type of Request|,
        lastUpdated => 0,
    },

    'comment label' => {
        message => q|Comment|,
        lastUpdated => 0,
    },

    'send button label' => {
        message => q|Send...|,
        lastUpdated => 0,
    },

    'show ratings' => {
        message => q|Show Ratings|,
        lastUpdated => 0,
    },

    'rate submit label' => {
        message => q|Rate|,
        lastUpdated => 0,
    },

    'detail template help title' => {
        lastUpdated => 0,
        message => q|Matrix Listing Detail Template Variables|,
	    context => q|The title of the help page for the matrix listing detail template.|,
    },

    'edit listing template help title' => {
        lastUpdated => 0,
        message => q|Edit Matrix Listing Template Variables|,
    	context => q|The title of the help page for the edit listing template.|,
    },

    'form' => {
        message => q|The complete edit form.|,
        lastUpdated => 0,
    	context => q|Description of the form tmpl_var for the template help.|,
    },

    'canEdit' => {
        message => q|A boolean indicating whether the user can edit this listing.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'editUrl' => {
        message => q|The url to this listing's edit screen.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'canApprove' => {
        message => q|A boolean indicating whether the user can approve or deny this listing.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'approveOrDenyUrl' => {
        message => q|The url to this listing's approve or deny screen.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'screenshots' => {
        message => q|This listings screenshots displayed using the ukplayer.|,
        lastUpdated => 0,
	    context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'comments' => {
        message => q|The comments attached to this listing.|,
    	lastUpdated => 0,
	    context => q|Description of the comments tmpl_var for the template help.|,
    },

    'emailForm' => {
    	message => q|A form to use to send an email to the listing maintainer.|,
	    lastUpdated => 0,
    	context => q|Description of the emailForm tmpl_var for the template help.|,
    },

    'emailSent' => {
        message => q|A condition indicating whether or not an email message was sent.|,
	    lastUpdated => 0,
    	context => q|Description of the emailSent tmpl_var for the template help.|,
    },

    'isPending' => {
        message => q|A conditional indicating whether or not this listing has been approved or not.|,
        lastUpdated => 1167186037,
        context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'lastUpdated_epoch' => {
        message => q|The epoch date of when this listing was last updated.|,
        lastUpdated => 0,
        context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'lastUpdated_date' => {
        message => q|A human readable date of when this listing was last updated.|,
        lastUpdated => 0,
        context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'description' => {
	message => q|The description of this listing.|,
	lastUpdated => 0,
        context => q|Description of the description tmpl_var for the template help.|,
    },

    'productName' => {
	message => q|The name of this listing. This is the same as this matrix listing's asset title.|,
	lastUpdated => 0,
        context => q|Description of the productName tmpl_var for the template help.|,
    },

    'productUrl' => {
	message => q|The manufacturer's URL for this listing.|,
	lastUpdated => 0,
        context => q|Description of the productUrl tmpl_var for the template help.|,
    },

    'productUrl_click' => {
	message => q|The product URL to use if you want to register the click count for this listing.|,
	lastUpdated => 0,
        context => q|Description of the productUrl_click tmpl_var for the template help.|,
    },

    'manufacturerUrl' => {
	message => q|The manufacturer's URL.|,
	lastUpdated => 0,
        context => q|Description of the manufacturerUrl tmpl_var for the template help.|,
    },

    'manufacturerUrl_click' => {
	message => q|The manufacturer URL to use if you want to register the click count for this listing.|,
	lastUpdated => 0,
        context => q|Description of the manufacturerUrl_click tmpl_var for the template help.|,
    },

    'views' => {
	message => q|The total number of views this listing has received.|,
	lastUpdated => 0,
        context => q|Description of the views tmpl_var for the template help.|,
    },

    'compares' => {
	message => q|The total number of compares this listing has received.|,
	lastUpdated => 0,
        context => q|Description of the compares tmpl_var for the template help.|,
    },

    'clicks' => {
	message => q|The total number of clicks this listing has received.|,
	lastUpdated => 0,
        context => q|Description of the clicks tmpl_var for the template help.|,
    },


    'version' => {
	message => q|The version of this listing.|,
	lastUpdated => 0,
        context => q|Description of the version tmpl_var for the template help.|,
    },

    'ratings' => {
	message => q|An overview of the ratings this listing has received and a form to rate this listing if the user hasn't rated it already.|,
	lastUpdated => 0,
        context => q|Description of the ratings tmpl_var for the template help.|,
    },

    'CATEGORY_NAME_loop' => {
	message => q|A loop containing attributes, and values for those attributes, is created for each category in this matrix. The name of the loop is the category name with spaces replaced with hyphens and a _loop added to the end. So if you have a category called "Bells and Whistles" then the loop would be called "bells-and-whistles_loop".|,
	lastUpdated => 1231764520,
	context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'categoryLabel' => {
	message => q|The label of this category.|,
	lastUpdated => 0,
	context => q|Description of the categoryLabel tmpl_var in the CATEGORY_NAME_loop for the template help.|,
    },

    'attribute_loop' => {
        message => q|A loop containing matrix attributes.|,
        lastUpdated => 0,
        context => q|Description of the attribute_loop tmpl_var for the template help.|,
    },

    'value' => {
	message => q|The value of this attribute.|,
	lastUpdated => 0,
	context => q|Description of the value tmpl_var in the attribute_loop for the template help.|,
    },

    'label' => {
	message => q|The label of this attribute.|,
	lastUpdated => 0,
	context => q|Description of the label tmpl_var in the attribute_loop for the template help.|,
    },

    'fieldType' => {
	message => q|The fieldType of this attribute.|,
	lastUpdated => 0,
	context => q|Description of the fieldType tmpl_var in the attribute_loop for the template help.|,
    },

    'Edit this listing.' => {
	message => q|Edit this listing.|,
	lastUpdated => 1230269571,
	context => q|i18n label for template.|,
    },

    'Approve this listing.' => {
	message => q|Approve this listing.|,
	lastUpdated => 1230269571,
	context => q|i18n label for template.|,
    },

    'Delete this listing.' => {
	message => q|Delete this listing.|,
	lastUpdated => 1230269571,
	context => q|i18n label for template.|,
    },

};

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_MatrixListing.pm <==
package WebGUI::i18n::English::Asset_MatrixListing;

use strict; 

our $I18N = { 
    'assetName' => {
        message => q|Matrix Listing|,
        lastUpdated => 0,
    },

    'edit matrix listing title' => {
        message => q|Edit/Add Listing|,
        lastUpdated => 0,
    },

    'template description' => {
        message => q|Select a template to be used to display the default view of the Matrix.|,
        lastUpdated => 0,
    },

    'template label' => {
        message => q|Matrix Listing Template|,
        lastUpdated => 0,
    },

    'screenshots description' => {
        message => q|Upload a picture of the product, or a screen shot if it's a software package.|,
        lastUpdated => 0,
    },

    'screenshots label' => {
        message => q|Screenshots/Photos|,
        lastUpdated => 0,
    },

    'description description' => {
        message => q|Please give a general description of the product.  Specific details can be rated in the form
fields below.|,
        lastUpdated => 0,
    },

    'description label' => {
        message => q|Description|,
        lastUpdated => 0,
    },

    'edit label' => {
        message => q|Edit|,
        lastUpdated => 0,
    },

    'version description' => {
        message => q|Enter the version/edition/model number for the product.|,
        lastUpdated => 0,
    },

    'version label' => {
        message => q|Version/Model|,
        lastUpdated => 0,
    },

    'last updated label' => {
        message => q|Last Updated|,
        lastUpdated => 0,
    },

    'web site label' => {
        message => q|Web Site|,
        lastUpdated => 0,
    },

    'message sent message' => {
        message => q|Message sent.|,
        lastUpdated => 0,
    },

    'contact maintainer label' => {
        message => q|Contact Maintainer|,
        lastUpdated => 0,
    },

    'maintainer description' => {
        message => q|If left blank, this will be the name of the user who created this product listing.  The
        listing maintainer is allowed to edit this listing, even if they are not members of the group
        to add or edit listings.|,
        lastUpdated => 0,
    },

    'maintainer label' => {
        message => q|Maintainer|,
        lastUpdated => 0,
    },

    'manufacturer label' => {
        message => q|Manufacturer|,
        lastUpdated => 0,
    },
    
    'manufacturerName description' => {
        message => q|The name of the company that manufactures the product or provides the service represented in
this listing.|,
        lastUpdated => 0,
    },

    'manufacturerName label' => {
        message => q|Manufacturer Name|,
        lastUpdated => 0,
    },

    'manufacturerURL description' => {
        message => q|If the manufacturer has a website, enter the complete URL for it here.|,
        lastUpdated => 0,
    },

    'manufacturerURL label' => {
        message => q|Manufacturer URL|,
        lastUpdated => 0,
    },

    'product name label' => {
        message => q|Product Name|,
        lastUpdated => 0,
    },

    'product name description' => {
        message => q|Enter the name of the product. If there are entries for the product with different revisions,
it would be best to make sure the names are the same.|,
        lastUpdated => 0,
    },

    'productURL description' => {
        message => q|If the product has its own website, enter the complete URL for it here.|,
        lastUpdated => 0,
    },

    'productURL label' => {
        message => q|Product URL|,
        lastUpdated => 0,
    },

    'mean label' => {
        message => q|Mean|,
        lastUpdated => 0,
    },

    'median label' => {
        message => q|Median|,
        lastUpdated => 0,
    },

    'count label' => {
        message => q|Count|,
        lastUpdated => 0,
    },

    'worst label' => {
        message => q|Worst|,
        lastUpdated => 0,
    },

    'respectable label' => {
        message => q|Respectable|,
        lastUpdated => 0,
    },

    'best label' => {
        message => q|Best|,
        lastUpdated => 0,
    },

    'your email label' => {
        message => q|Your Email Address|,
        lastUpdated => 0,
    },

    'report error label' => {
        message => q|Report an error.|,
        lastUpdated => 0,
    },

    'general comment label' => {
        message => q|General comment.|,
        lastUpdated => 0,
    },

    'request type label' => {
        message => q|Type of Request|,
        lastUpdated => 0,
    },

    'comment label' => {
        message => q|Comment|,
        lastUpdated => 0,
    },

    'send button label' => {
        message => q|Send...|,
        lastUpdated => 0,
    },

    'show ratings' => {
        message => q|Show Ratings|,
        lastUpdated => 0,
    },

    'rate submit label' => {
        message => q|Rate|,
        lastUpdated => 0,
    },

    'detail template help title' => {
        lastUpdated => 0,
        message => q|Matrix Listing Detail Template Variables|,
	    context => q|The title of the help page for the matrix listing detail template.|,
    },

    'edit listing template help title' => {
        lastUpdated => 0,
        message => q|Edit Matrix Listing Template Variables|,
    	context => q|The title of the help page for the edit listing template.|,
    },

    'form' => {
        message => q|The complete edit form.|,
        lastUpdated => 0,
    	context => q|Description of the form tmpl_var for the template help.|,
    },

    'canEdit' => {
        message => q|A boolean indicating whether the user can edit this listing.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'editUrl' => {
        message => q|The url to this listing's edit screen.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'canApprove' => {
        message => q|A boolean indicating whether the user can approve or deny this listing.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'approveOrDenyUrl' => {
        message => q|The url to this listing's approve or deny screen.|,
        lastUpdated => 0,
        context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'screenshots' => {
        message => q|This listings screenshots displayed using the ukplayer.|,
        lastUpdated => 0,
	    context => q|Description of the screenshots tmpl_var for the template help.|,
    },

    'comments' => {
        message => q|The comments attached to this listing.|,
    	lastUpdated => 0,
	    context => q|Description of the comments tmpl_var for the template help.|,
    },

    'emailForm' => {
    	message => q|A form to use to send an email to the listing maintainer.|,
	    lastUpdated => 0,
    	context => q|Description of the emailForm tmpl_var for the template help.|,
    },

    'emailSent' => {
        message => q|A condition indicating whether or not an email message was sent.|,
	    lastUpdated => 0,
    	context => q|Description of the emailSent tmpl_var for the template help.|,
    },

    'isPending' => {
        message => q|A conditional indicating whether or not this listing has been approved or not.|,
        lastUpdated => 1167186037,
        context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'lastUpdated_epoch' => {
        message => q|The epoch date of when this listing was last updated.|,
        lastUpdated => 0,
        context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'lastUpdated_date' => {
        message => q|A human readable date of when this listing was last updated.|,
        lastUpdated => 0,
        context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'description' => {
	message => q|The description of this listing.|,
	lastUpdated => 0,
        context => q|Description of the description tmpl_var for the template help.|,
    },

    'productName' => {
	message => q|The name of this listing. This is the same as this matrix listing's asset title.|,
	lastUpdated => 0,
        context => q|Description of the productName tmpl_var for the template help.|,
    },

    'productUrl' => {
	message => q|The manufacturer's URL for this listing.|,
	lastUpdated => 0,
        context => q|Description of the productUrl tmpl_var for the template help.|,
    },

    'productUrl_click' => {
	message => q|The product URL to use if you want to register the click count for this listing.|,
	lastUpdated => 0,
        context => q|Description of the productUrl_click tmpl_var for the template help.|,
    },

    'manufacturerUrl' => {
	message => q|The manufacturer's URL.|,
	lastUpdated => 0,
        context => q|Description of the manufacturerUrl tmpl_var for the template help.|,
    },

    'manufacturerUrl_click' => {
	message => q|The manufacturer URL to use if you want to register the click count for this listing.|,
	lastUpdated => 0,
        context => q|Description of the manufacturerUrl_click tmpl_var for the template help.|,
    },

    'views' => {
	message => q|The total number of views this listing has received.|,
	lastUpdated => 0,
        context => q|Description of the views tmpl_var for the template help.|,
    },

    'compares' => {
	message => q|The total number of compares this listing has received.|,
	lastUpdated => 0,
        context => q|Description of the compares tmpl_var for the template help.|,
    },

    'clicks' => {
	message => q|The total number of clicks this listing has received.|,
	lastUpdated => 0,
        context => q|Description of the clicks tmpl_var for the template help.|,
    },


    'version' => {
	message => q|The version of this listing.|,
	lastUpdated => 0,
        context => q|Description of the version tmpl_var for the template help.|,
    },

    'ratings' => {
	message => q|An overview of the ratings this listing has received and a form to rate this listing if the user hasn't rated it already.|,
	lastUpdated => 0,
        context => q|Description of the ratings tmpl_var for the template help.|,
    },

    'CATEGORY_NAME_loop' => {
	message => q|A loop containing attributes, and values for those attributes, is created for each category in this matrix. The name of the loop is the category name with spaces replaced with hyphens and a _loop added to the end. So if you have a category called "Bells and Whistles" then the loop would be called "bells-and-whistles_loop".|,
	lastUpdated => 1231764520,
	context => q|Description of the CATEGORY_NAME_loop tmpl_var for the template help.|,
    },

    'categoryLabel' => {
	message => q|The label of this category.|,
	lastUpdated => 0,
	context => q|Description of the categoryLabel tmpl_var in the CATEGORY_NAME_loop for the template help.|,
    },

    'attribute_loop' => {
        message => q|A loop containing matrix attributes.|,
        lastUpdated => 0,
        context => q|Description of the attribute_loop tmpl_var for the template help.|,
    },

    'value' => {
	message => q|The value of this attribute.|,
	lastUpdated => 0,
	context => q|Description of the value tmpl_var in the attribute_loop for the template help.|,
    },

    'label' => {
	message => q|The label of this attribute.|,
	lastUpdated => 0,
	context => q|Description of the label tmpl_var in the attribute_loop for the template help.|,
    },

    'fieldType' => {
	message => q|The fieldType of this attribute.|,
	lastUpdated => 0,
	context => q|Description of the fieldType tmpl_var in the attribute_loop for the template help.|,
    },

    'Edit this listing.' => {
	message => q|Edit this listing.|,
	lastUpdated => 1230269571,
	context => q|i18n label for template.|,
    },

    'Approve this listing.' => {
	message => q|Approve this listing.|,
	lastUpdated => 1230269571,
	context => q|i18n label for template.|,
    },

    'Delete this listing.' => {
	message => q|Delete this listing.|,
	lastUpdated => 1230269571,
	context => q|i18n label for template.|,
    },

    'Send Creator a Message' => {
        lastUpdated => 1250146133,
        message => q|Send Creator a Message|,
        context => q|Creator, the person who created this listing|,
    },

};

1;
